#
# spec file for package smp_utils
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname   libsmputils1-1
Name:           smp_utils
Version:        0.99
Release:        2.10
Summary:        Utilities for the SAS Management Protocol (SMP)
License:        BSD-3-Clause AND GPL-2.0-only
Group:          Hardware/Other
Source:         http://sg.danny.cz/sg/p/%{name}-%{version}.tar.xz
Provides:       scsi:%{_bindir}/smp_conf_general
Provides:       scsi:%{_bindir}/smp_conf_route_info
Provides:       scsi:%{_bindir}/smp_discover
Provides:       scsi:%{_bindir}/smp_discover_list
Provides:       scsi:%{_bindir}/smp_phy_control
Provides:       scsi:%{_bindir}/smp_phy_test
Provides:       scsi:%{_bindir}/smp_read_gpio
Provides:       scsi:%{_bindir}/smp_rep_exp_route_tbl
Provides:       scsi:%{_bindir}/smp_rep_general
Provides:       scsi:%{_bindir}/smp_rep_manufacturer
Provides:       scsi:%{_bindir}/smp_rep_phy_err_log
Provides:       scsi:%{_bindir}/smp_rep_phy_sata
Provides:       scsi:%{_bindir}/smp_rep_route_info
Provides:       scsi:%{_bindir}/smp_write_gpio

%description
The smp_utils package contains utilities for the Serial Attached SCSI
(SAS) Management Protocol (SMP).  Most utilities correspond to a single
SMP function, sending out a request, checking for errors and if all is
well processing the response. The response is either decoded, printed
out in ASCII hexadecimal or sent as binary to stdout.

%package -n %{lname}
Summary:        Library for SAS SMP control of expanders
Group:          System/Libraries

%description -n %{lname}
The smp_utils package contains utilities for the Serial Attached SCSI
(SAS) Management Protocol (SMP).

This subpackage holds the library of shared functions.

%package -n libsmputils-devel
Summary:        Development files for the SAS SMP Expander Control Library
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description -n libsmputils-devel
The smp_utils package contains utilities for the Serial Attached SCSI
(SAS) Management Protocol (SMP).

This subpackage contains libraries and header files for developing
applications that want to make use of libsmputils.

%prep
%setup -q

%build
%configure --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post   -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files
# smp_utils
%doc README ChangeLog
%license COPYING
%{_bindir}/smp_*
%{_mandir}/man8/*.8%{?ext_man}

%files -n %{lname}
%{_libdir}/libsmputils1.so.1*

%files -n libsmputils-devel
%{_includedir}/scsi/
%{_libdir}/libsmputils1.so

%changelog
* Wed Nov 11 2020 Jan Engelhardt <jengelh@inai.de>
- Add missing ldconfig calls for libsmputils1-1.
* Thu Apr 16 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.99:
  - smp_discover(_list): add --dsn option to show
    device slot number in single line per phy summary
  - attached SAS device type, word SAS added (spl4r01)
  - add SAS connector types, shared with NVMe (ses3r8)
  - add buffered phy burst size field (spl4r07)
  - add attached apta capable field
  - update phy capabilities decode (spl5r02)
  - use Report general to get number phys rather
    than loop until an error occurs
  - smp_rep_general: add extended fairness field
  - add initial time to delay expander forward open
    indication field
  - add external port field (spl5r02)
  - smp_phy_test: change default linkrate from 3 to 6 Gbps
    which is value 0xa
  - smp_conf_phy_event: fix file pointer leak
  - add G5 (22.5 Gbps for SAS-4) settings [spl4r06]
  - convert many two valued ints to bools
  - smp_lib:
  - add smp_get_connector_type_str(), smp_get_num_nomult()
    and smp_get_llnum_nomult()
  - add dStrHexErr() and dStrHexStr()
  - add hex2stdout, hex2stderr and hex2str
  - add smp_is_big_endian(), smp_all_zeros() and
    smp_all_ffs()
  - add sg_unaligned.h and sg_pr2serr.h headers
  - change connector name: 'SAS SlimLine' to 'SlimSAS'
  - sync with spl5r08
  - cleanup configure.ac + Makefile.am
  - update BSD license from 3 to 2 clause aka FreeBSD
    license (without reference to FreeBSD project)
  - debian: bump compat file contents from 7 to 10
- Drop no longer needed sysmacros.patch
* Wed Aug  1 2018 schwab@suse.de
- sysmacros.patch: Include <sys/sysmacros.h> for major/minor/makedev
* Wed Mar 25 2015 p.drouand@gmail.com
- Update to version 0.98
  * add Linux aacraid support, interface name : aac
  - device name has form /dev/aac[N[,E_ID]]
  * smp_discover, smp_discover_list: in 1 line summary use
    routing attribute "U" instead of "T" if "table to
    table supported" set in report general response
  - output device slot (group) number if len > 109
  - add 'attached persistent capable' bit (spl3r2)
  - add pwr_dis_* fields (spl3r3)
  - add '--cap' option to decode phy capabilities
  - change 'end device' to 'SAS or SATA device'
  * smp_discover: '-mm' produces full output for each phy
  * smp_rep_broadcast: add broadcast type names
  * smp_general: add 'initiates ssp close' and 'ssp
    maximum connect time limit' fields (spl3r04)
  * add support for mpt3ctl (Linux LSI 12 Gbps HBAs)
  * change binary install from /usr/sbin to /usr/bin since
    sbin caused problems
  * examples folder scripts cleanup
  * make code more C11/C++ friendly
* Thu Jun 13 2013 jengelh@inai.de
- Update to new upstream release 0.95
  * mpt: cope with mpt2 ioctl that uses a different magic number
- Update to new upstream release 0.96
  * New utilities: smp_conf_zone_perm_tbl, smp_conf_zone_man_pass,
  smp_conf_zone_phy_info, smp_ena_dis_zoning, smp_rep_broadcast,
  smp_rep_phy_event, smp_rep_phy_event_list,
  smp_rep_self_conf_stat, smp_rep_zone_man_pass,
  smp_rep_zone_perm_tbl, smp_zone_activate, smp_zoned_broadcast,
  smp_zone_lock, smp_zone_unlock:
  * Allow specifying --phy= IDs up to 254
- Update to new upstream release 0.97
  * New utilitiy: smp_conf_phy_event
  * Synchronize to SPL-2 r03
  * smp_rep_phy_event, smp_rep_phy_event_list: add --enumerate
  option to list Phy Event Source names
- Now builds using autotools, changed %%build/%%install accordingly.
- Remove smp_utils-Makefile.diff (no longer applicable),
  smp_utils-compile-fixes (no longer applies)
- Simplify filelists. Remove redundant %%clean section.
* Fri Mar  1 2013 cfarrell@suse.com
- license update: BSD-3-Clause and GPL-2.0
  See mptctl.h
* Thu Feb 28 2013 coolo@suse.com
- update license to new format
* Fri Sep 30 2011 uli@suse.com
- cross-build fix: use %%__cc macro
* Thu Mar 12 2009 hare@suse.de
- Update to smp_utils-0.94 (bnc#483393)
  - smp_discover: sync to sas2r15
  - smp_discover_list: sync to sas2r15
  - smp_rep_general: sync to sas2r15
  - smp_rep_exp_route_tbl: sync to sas2r15
  - smp_lib: sync to sas2r15
  - sgv4: more detail in error messages
  - sgv4: drop scsi.h include, gives problems with lk 2.6.27
  - mpt: allow either /dev/mptctl or /dev/mpt2ctl [10;220-221]
  - warn if target SAS address is 0x00000000 when -v given
* Fri May 23 2008 hare@suse.de
- using 'Provides' to clean update dependency
* Thu Apr 24 2008 hare@suse.de
- Split off from original scsi package.
